#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: lens
version: 4.15.4
id: lens-4.15.4-GH6g8mH8MFUClTlMTyxH3q
key: lens-4.15.4-GH6g8mH8MFUClTlMTyxH3q
license: BSD2
copyright: Copyright (C) 2012-2016 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/lens/
synopsis: Lenses, Folds and Traversals
description:
    This package comes \"Batteries Included\" with many useful lenses for the types
    commonly used from the Haskell Platform, and with tools for automatically
    generating lenses and isomorphisms for user-supplied data types.
    .
    The combinators in @Control.Lens@ provide a highly generic toolbox for composing
    families of getters, folds, isomorphisms, traversals, setters and lenses and their
    indexed variants.
    .
    An overview, with a large number of examples can be found in the <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals README>.
    .
    An introductory video on the style of code used in this library by Simon Peyton Jones is available from <http://skillsmatter.com/podcast/scala/lenses-compositional-data-access-and-manipulation Skills Matter>.
    .
    A video on how to use lenses and how they are constructed is available on <http://youtu.be/cefnmjtAolY?hd=1 youtube>.
    .
    Slides for that second talk can be obtained from <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf comonad.com>.
    .
    More information on the care and feeding of lenses, including a brief tutorial and motivation
    for their types can be found on the <https://github.com/ekmett/lens/wiki lens wiki>.
    .
    A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the <https://github.com/ekmett/lens/blob/master/examples/ example folder>.
    .
    /Lenses, Folds and Traversals/
    .
    With some signatures simplified, the core of the hierarchy of lens-like constructions looks like:
    .
    .
    <<http://i.imgur.com/ALlbPRa.png>>
    .
    <Hierarchy.png (Local Copy)>
    .
    You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
    use any element of the hierarchy as any type it linked to above it.
    .
    The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
    .
    For instance:
    .
    * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
    .
    * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
    .
    /Minimizing Dependencies/
    .
    If you want to provide lenses and traversals for your own types in your own libraries, then you
    can do so without incurring a dependency on this (or any other) lens package at all.
    .
    /e.g./ for a data type:
    .
    > data Foo a = Foo Int Int a
    .
    You can define lenses such as
    .
    > -- bar :: Lens'\'' (Foo a) Int
    > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
    > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
    .
    > -- quux :: Lens (Foo a) (Foo b) a b
    > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
    > quux f (Foo a b c) = fmap (Foo a b) (f c)
    .
    without the need to use any type that isn'\''t already defined in the @Prelude@.
    .
    And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
    .
    > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
    > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
    > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
    .
    What is provided in this library is a number of stock lenses and traversals for
    common haskell types, a wide array of combinators for working them, and more
    exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses, Generics
author: Edward A. Kmett
exposed: True
indefinite: False
exposed-modules:
    Control.Exception.Lens Control.Lens Control.Lens.At
    Control.Lens.Combinators Control.Lens.Cons Control.Lens.Each
    Control.Lens.Empty Control.Lens.Equality Control.Lens.Extras
    Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
    Control.Lens.Internal Control.Lens.Internal.Bazaar
    Control.Lens.Internal.ByteString Control.Lens.Internal.CTypes
    Control.Lens.Internal.Coerce Control.Lens.Internal.Context
    Control.Lens.Internal.Deque Control.Lens.Internal.Exception
    Control.Lens.Internal.FieldTH Control.Lens.Internal.Fold
    Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
    Control.Lens.Internal.Instances Control.Lens.Internal.Iso
    Control.Lens.Internal.Level Control.Lens.Internal.List
    Control.Lens.Internal.Magma Control.Lens.Internal.Prism
    Control.Lens.Internal.PrismTH Control.Lens.Internal.Review
    Control.Lens.Internal.Setter Control.Lens.Internal.TH
    Control.Lens.Internal.Zoom Control.Lens.Iso Control.Lens.Lens
    Control.Lens.Level Control.Lens.Operators Control.Lens.Plated
    Control.Lens.Prism Control.Lens.Reified Control.Lens.Review
    Control.Lens.Setter Control.Lens.TH Control.Lens.Traversal
    Control.Lens.Tuple Control.Lens.Type Control.Lens.Wrapped
    Control.Lens.Zoom Control.Monad.Error.Lens
    Control.Parallel.Strategies.Lens Control.Seq.Lens Data.Array.Lens
    Data.Bits.Lens Data.ByteString.Lazy.Lens Data.ByteString.Lens
    Data.ByteString.Strict.Lens Data.Complex.Lens Data.Data.Lens
    Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
    Data.Map.Lens Data.Sequence.Lens Data.Set.Lens Data.Text.Lazy.Lens
    Data.Text.Lens Data.Text.Strict.Lens Data.Tree.Lens
    Data.Typeable.Lens Data.Vector.Generic.Lens Data.Vector.Lens
    GHC.Generics.Lens Language.Haskell.TH.Lens Numeric.Lens
    System.Exit.Lens System.FilePath.Lens System.IO.Error.Lens
hidden-modules: Paths_lens
abi: 2a0e34ead854f7cce16655221d59d6aa
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/lens-4.15.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/lens-4.15.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/lens-4.15.4
hs-libraries: HSlens-4.15.4-GH6g8mH8MFUClTlMTyxH3q
depends:
    array-0.5.2.0 base-4.10.1.0 base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4
    bifunctors-5.4.2-Cctfp3LopdNGpYrwymp5RT bytestring-0.10.8.2
    call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei
    comonad-5.0.2-5FGZALTgAAwCV8EmXasfw1
    contravariant-1.4-7z11WOqE85DGeP9JdLBkE1 containers-0.5.10.2
    distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE filepath-1.4.1.2
    free-4.12.4-C4p86mT2P2b4N7ja0LP1KZ ghc-prim-0.5.1.1
    hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy
    kan-extensions-5.0.2-9hj7RmxuaeyHL5PQlAUuFt
    exceptions-0.8.3-KXvLXRbxEkO6vroqtRG1UV
    mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH
    parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1
    profunctors-5.2.1-KIZgcqCKkIPB9C6XrPs4zD
    reflection-2.1.2-C2CXGjPrlDWEm9x409Gv1U
    semigroupoids-5.2.1-159o3FQm8wLAkIaxuoQCLq
    semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7
    tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2 template-haskell-2.12.0.0
    th-abstraction-0.2.6.0-KdJUlqAwMfUIgxZVMgLLVd
    text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj transformers-0.5.2.0
    transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM
    unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV
    vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4
    void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC
abi-depends: array-0.5.2.0=26dc06837667b4f45ea7fe07c114ff89
             base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             base-orphans-0.6-KoJqNefbvUAEuaR7CDOiu4=1ea863fa192fc45e8d2cbbea64399d3f
             bifunctors-5.4.2-Cctfp3LopdNGpYrwymp5RT=167cc4ae9d826c79e7c57081d69bb5d6
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             call-stack-0.1.0-BVjoAlBRe9FCSr5eFfllei=f637009e526e2490e52d1ac470f88ae2
             comonad-5.0.2-5FGZALTgAAwCV8EmXasfw1=3624ae78f5a7be009a9ebe3e191d5ef0
             contravariant-1.4-7z11WOqE85DGeP9JdLBkE1=6a2b43384be6c8f5f492b023fa24d502
             containers-0.5.10.2=cc49645af4ed58d1819a7e09ee1f7920
             distributive-0.5.3-3QQWO3yfOScASLf5zUz2JE=9f8452151d097c3dbc68cb5512a37843
             filepath-1.4.1.2=f49190c9093d895f9f159c40e7d1ff46
             free-4.12.4-C4p86mT2P2b4N7ja0LP1KZ=6203e234c5b8795ceed5cb96ad20748e
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             hashable-1.2.6.1-9ZXmUmZR8Ja1wkFjzrwxTy=0960747f6d33db66637f40f842025f18
             kan-extensions-5.0.2-9hj7RmxuaeyHL5PQlAUuFt=c0e3ef99719ac675f538ed8bdf8680d4
             exceptions-0.8.3-KXvLXRbxEkO6vroqtRG1UV=a65573b768f12b6581738ace5752a912
             mtl-2.2.1-DscMMmDQUE6GBfOSl4qMUH=1e76d6f7019a4b5c8c222b2fbbb06681
             parallel-3.2.1.1-6PIhrl6oqe7Af1Z2sa6T1=8e776fe3690179bf950ef68b6c149b55
             profunctors-5.2.1-KIZgcqCKkIPB9C6XrPs4zD=315ef14f980cf29ea67e6269656c2b3d
             reflection-2.1.2-C2CXGjPrlDWEm9x409Gv1U=d48f6cf8598ae9dd63dc0c4832c13292
             semigroupoids-5.2.1-159o3FQm8wLAkIaxuoQCLq=794659b8c7861b2dc4bc4f6a8e1b1696
             semigroups-0.18.3-3aCIuYG4ID286XaN6MuQu7=863c6a42773abd5c980b4318cc858c44
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=4764468d99de060aada7572c7b2f4378
             template-haskell-2.12.0.0=2257617827b0258ca46e933b344007b7
             th-abstraction-0.2.6.0-KdJUlqAwMfUIgxZVMgLLVd=e39297a399602642b45643ca1a00bc5f
             text-1.2.2.2-E3rQA0mJl73IvZIzvmwqAj=168216a11cdc39c8cc50d80b9c45a385
             transformers-0.5.2.0=e04579c0363c9229351d1a0b394bf2d5
             transformers-compat-0.5.1.4-EAh8Ccrgitz4vTZtbTPyCM=94a5340d64a5db3506fe5654c7b40389
             unordered-containers-0.2.8.0-I4wGGMV7X9X97sk1hrOqCV=b12cdae8ac228affcce9703d4cef3dce
             vector-0.12.0.1-IUGn3M9mkBh8CyXcBnfTR4=aa687f07efbeaeb82a30478c8f07e96e
             void-0.7.2-FiGeS4PZxPp8gUDrtvjFKC=2129d94dd9a574dcd2d2bc46dca144d6
haddock-interfaces: /usr/share/doc/haskell-lens/html/lens.haddock
haddock-html: /usr/share/doc/haskell-lens/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

